@@ -4,7 +4,7 @@ package Test::Class::Moose::Report;
 
 use 5.10.0;
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 use Carp;
 use Moose;
@@ -133,7 +133,8 @@ sub _populate_control_timing_data {
     my $report  = shift;
 
     for my $control (@_) {
-        my $control_method = $report->${ \( $control . '_method' ) };
+        my $control_method = $report->${ \( $control . '_method' ) }
+          or next;
         $hashref->{control}{$control}{time}
           = $control_method->time->as_hashref;
     }
@@ -155,7 +156,7 @@ Test::Class::Moose::Report - Test information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.64
+version 0.65
 
 =head1 SYNOPSIS
 
